PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Track.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Enumerations
Track.hpp File Reference
`#include "AShape.hpp"`
`#include "Path.hpp"`
`#include "Via.hpp"`

Go to the source code of this file.

## Data Structures
class | Track

## Enumerations
enum class | ContactType { NONE = 0 , END_TO_START = 1 , END_TO_END = 2 , START_TO_END = 3 , START_TO_START = 4 }

## Enumeration Type Documentation

## ◆ ContactType

enum class ContactType
| strong

Enumerator
NONE |
END_TO_START |
END_TO_END |
START_TO_END |
START_TO_START |